# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import gettext_lazy as _
from jmb.filters.admin import AdvancedSearchModelAdmin
from thx.core.admin import UserAdminMixin

from . import models


class AdministrativeAreaInline(admin.TabularInline):
    model = models.AdministrativeArea
    extra = 0
    fields = ('status', 'name', 'abbrev', 'ordering',)


class CountryAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('name',)
    advanced_search_fields = (
        ('iso2_code__iexact', 'iso3_code__icontains',),
        ('name__icontains', 'printable_name__icontains',),
    )
    list_filter = ('status', 'continent', 'admin_area',)
    fieldsets = (
        (_("denomination"), {
            'fields': ('printable_name', 'name'),
        }),
        (_("codes"), {
            'fields': ('iso2_code', 'iso3_code', 'numcode',)
        }),
        (None, {
            'fields': ('continent', 'admin_area',),
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('iso2_code', 'status', 'name', 'printable_name', 'ordering')
    list_display_links = ('name', 'printable_name')
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    inlines = (AdministrativeAreaInline,)


class AdministrativeAreaAdmin(
    UserAdminMixin, AdvancedSearchModelAdmin, admin.ModelAdmin
):
    search_fields = ('name',)
    advanced_search_fields = (
        ('abbrev__icontains', 'country__name__icontains',),
    )
    list_filter = ('status',)
    fieldsets = (
        (_('general information'), {
            'fields': ('country', 'name', 'abbrev',),
        }),
        (_('visualization admin'), {
            'classes': ('collapse',),
            'fields': ('ordering', 'status')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    list_display = ('id', 'status', 'country', 'name', 'abbrev', 'ordering')
    list_display_links = ('name',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    autocomplete_fields = ('country',)


admin.site.register(models.Country, CountryAdmin)
admin.site.register(models.AdministrativeArea, AdministrativeAreaAdmin)
