# -*- coding: utf-8 -*-

import urllib

import requests
from django.urls import reverse


class RemoteTestMixin:
    # COUNTRY
    def v1_l10n_country_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-l10n:country-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_l10n_country_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-l10n:country-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_l10n_country_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-l10n:country-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_l10n_country_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-l10n:country-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_l10n_country_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-l10n:country-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_l10n_country_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-l10n:country-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_l10n_country_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-l10n:country-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_l10n_country_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-l10n:country-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_l10n_country_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-l10n:country-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
    # ADMINISTRATIVE AREA

    def v1_l10n_administrative_area_list(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-l10n:administrativearea-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_l10n_administrative_area_retrieve(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-l10n:administrativearea-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_l10n_administrative_area_create(self, profile, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-l10n:administrativearea-list',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_l10n_administrative_area_update(self, profile, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-l10n:administrativearea-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_l10n_administrative_area_enable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-l10n:administrativearea-enable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_l10n_administrative_area_disable(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-l10n:administrativearea-disable',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_l10n_administrative_area_destroy(self, profile, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-l10n:administrativearea-detail',
            args=(profile, pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_l10n_administrative_area_light(self, profile, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-l10n:administrativearea-light',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_l10n_administrative_area_status_choices(self, profile):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-l10n:administrativearea-status-choices',
            args=(profile,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
