# -*- coding: utf-8 -*-

from rest_framework import serializers
from thx.api.serializers import (
    ThuxCreateSerializerMixin, ThuxDisableSerializerMixin, ThuxEnableSerializerMixin, ThuxListSerializerMixin,
    ThuxPartialUpdateSerializerMixin, ThuxRetrieveSerializerMixin, ThuxUpdateSerializerMixin,
)

from ... import models


# COUNTRY
class CountrySerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country'
        model = models.Country
        fields = '__all__'


class CountryListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country_list'
        model = models.Country
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class CountryRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country_retrieve'
        model = models.Country
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class CountryCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country_create'
        model = models.Country
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = CountryRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class CountryUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country_update'
        model = models.Country
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = CountryRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class CountryPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country_partial_update'
        model = models.Country
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = CountryRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class CountryEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country_enable'
        model = models.Country
        fields = ()
        response_serializer = CountryRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class CountryDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country_disable'
        model = models.Country
        fields = ()
        response_serializer = CountryRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class CountryLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_country_light'
        model = models.Country
        fields = ('iso2_code', 'status', 'status_display',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


# ADMINISTRATIVE AREA
class AdministrativeAreaSerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_administrative_area'
        model = models.AdministrativeArea
        fields = '__all__'


class AdministrativeAreaListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    country = CountryRetrieveSerializer()

    class Meta:
        ref_name = 'v1_l10n_administrative_area_list'
        model = models.AdministrativeArea
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class AdministrativeAreaRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    country = CountryRetrieveSerializer()

    class Meta:
        ref_name = 'v1_l10n_administrative_area_retrieve'
        model = models.AdministrativeArea
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class AdministrativeAreaCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_administrative_area_create'
        model = models.AdministrativeArea
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = AdministrativeAreaRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class AdministrativeAreaUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_administrative_area_update'
        model = models.AdministrativeArea
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = AdministrativeAreaRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class AdministrativeAreaPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_administrative_area_partial_update'
        model = models.AdministrativeArea
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = AdministrativeAreaRetrieveSerializer

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class AdministrativeAreaEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_administrative_area_enable'
        model = models.AdministrativeArea
        fields = ()
        response_serializer = AdministrativeAreaRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class AdministrativeAreaDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_administrative_area_disable'
        model = models.AdministrativeArea
        fields = ()
        response_serializer = AdministrativeAreaRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class AdministrativeAreaLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_l10n_administrative_area_light'
        model = models.AdministrativeArea
        fields = ('id', 'status', 'status_display',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs.get('profile')
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []
